PseudoInv: Moore-Penrose Pseudo Inverse of A Matrix
Description
Calculate the Moore-Penrose pseudo inverse of matrix Y up to a given rankUsage
PseudoInv(Y, k, svd.method = "fast")
Arguments
svd.method
either "fast", "propack" or "standard".
"fast" is using the fast.svd function in package corpcor to compute SVD, "propack" is using the propack.svd Value
- A pseudo-inverse matrix of rank
k
Details
This function does similar things as ginv in package MASS while controls
the rank.